@@ -1,4 +1,4 @@
-from django.utils.translation import gettext as _
+from django.utils.translation import gettext_lazy as _
 
 from djangocms_frontend.models import FrontendUIItem
 
@@ -11,6 +11,7 @@ class Accordion(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Accordion")
 
     def get_short_description(self):
         return _("({} entries)").format(self.get_children_count())
@@ -22,8 +23,11 @@ class AccordionItem(FrontendUIItem):
     https://getbootstrap.com/docs/5.0/components/accordion/
     """
 
+    _("AccordionItem")
+
     class Meta:
         proxy = True
+        verbose_name = _("Accordion item")
 
     def get_short_description(self):
         return getattr(self, "accordion_item_header", "-")
