@@ -3,15 +3,23 @@ from django.utils.translation import gettext_lazy as _
 from entangled.forms import EntangledModelForm
 
 from djangocms_frontend import settings
+from djangocms_frontend.common.responsive import ResponsiveFormMixin
+from djangocms_frontend.common.spacing import SpacingFormMixin
 from djangocms_frontend.contrib import alert
-from djangocms_frontend.fields import AttributesFormField, ColoredButtonGroup
+from djangocms_frontend.fields import (
+    AttributesFormField,
+    ColoredButtonGroup,
+    TagTypeFormField,
+)
 from djangocms_frontend.models import FrontendUIItem
 from djangocms_frontend.settings import COLOR_STYLE_CHOICES
 
 mixin_factory = settings.get_forms(alert)
 
 
-class AlertForm(mixin_factory("Alert"), EntangledModelForm):
+class AlertForm(
+    mixin_factory("Alert"), ResponsiveFormMixin, SpacingFormMixin, EntangledModelForm
+):
     """
     Components > "Alerts" Plugin
     https://getbootstrap.com/docs/5.0/components/alerts/
@@ -41,3 +49,4 @@ class AlertForm(mixin_factory("Alert"), EntangledModelForm):
         help_text=_("Allows the alert to be closed."),
     )
     attributes = AttributesFormField()
+    tag_type = TagTypeFormField()
