@@ -6,7 +6,7 @@ from entangled.forms import EntangledModelForm
 from filer.fields.image import AdminImageFormField, FilerImageField
 from filer.models import Image
 
-from djangocms_frontend.fields import AttributesFormField
+from djangocms_frontend.fields import AttributesFormField, TagTypeFormField
 
 from ... import settings
 from ...models import FrontendUIItem
@@ -48,6 +48,9 @@ class CarouselForm(EntangledModelForm):
         choices=CAROUSEL_TEMPLATE_CHOICES,
         initial=CAROUSEL_TEMPLATE_CHOICES[0][0],
         help_text=_("This is the template that will be used for the component."),
+        widget=forms.HiddenInput
+        if len(CAROUSEL_TEMPLATE_CHOICES) < 2
+        else forms.Select,
     )
     carousel_interval = forms.IntegerField(
         label=_("Interval"),
@@ -123,6 +126,7 @@ class CarouselForm(EntangledModelForm):
             "data-bs-wrap",
         ],
     )
+    tag_type = TagTypeFormField()
 
 
 class CarouselSlideForm(AbstractLinkForm, EntangledModelForm):
@@ -157,3 +161,4 @@ class CarouselSlideForm(AbstractLinkForm, EntangledModelForm):
         help_text=_("Content may also be added using child plugins."),
     )
     attributes = AttributesFormField()
+    tag_type = TagTypeFormField()
