@@ -1,3 +1,5 @@
+from django.utils.translation import gettext_lazy as _
+
 from ...models import FrontendUIItem
 
 
@@ -9,9 +11,10 @@ class CodeBlock(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Code block")
 
     def get_short_description(self):
-        return "<{}>".format(self.code_type)
+        return f"<{self.code_type}>"
 
 
 class Blockquote(FrontendUIItem):
@@ -22,6 +25,7 @@ class Blockquote(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Blockquote")
 
     def get_short_description(self):
         return self.quote_content
@@ -35,6 +39,7 @@ class Figure(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Figure")
 
     def get_short_description(self):
         return self.figure_caption
