@@ -1,8 +1,10 @@
-from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from django.utils.translation import gettext_lazy as _
 
 from ... import settings
+from ...cms_plugins import CMSUIPlugin
+from ...common.attributes import AttributesMixin
+from ...common.responsive import ResponsiveMixin
 from .. import media
 from . import forms, models
 
@@ -10,7 +12,9 @@ mixin_factory = settings.get_renderer(media)
 
 
 @plugin_pool.register_plugin
-class MediaPlugin(mixin_factory("Media"), CMSPluginBase):
+class MediaPlugin(
+    mixin_factory("Media"), AttributesMixin, ResponsiveMixin, CMSUIPlugin
+):
     """
     Layout > "Media" Plugin
     http://getbootstrap.com/docs/4.0/layout/media-object/
@@ -20,26 +24,14 @@ class MediaPlugin(mixin_factory("Media"), CMSPluginBase):
     module = _("Frontend")
     model = models.Media
     form = forms.MediaForm
-    render_template = f"djangocms_frontend/{settings.framework}/media.html"
     change_form_template = "djangocms_frontend/admin/media.html"
     allow_children = True
 
-    fieldsets = [
-        (
-            _("Advanced settings"),
-            {
-                "classes": ("collapse",),
-                "fields": (
-                    "tag_type",
-                    "attributes",
-                ),
-            },
-        ),
-    ]
+    fieldsets = settings.EMPTY_FIELDSET
 
 
 @plugin_pool.register_plugin
-class MediaBodyPlugin(mixin_factory("MediaBody"), CMSPluginBase):
+class MediaBodyPlugin(mixin_factory("MediaBody"), AttributesMixin, CMSUIPlugin):
     """
     Layout > "Media body" Plugin
     http://getbootstrap.com/docs/4.0/layout/media-object/
@@ -49,20 +41,8 @@ class MediaBodyPlugin(mixin_factory("MediaBody"), CMSPluginBase):
     module = _("Frontend")
     model = models.MediaBody
     form = forms.MediaBodyForm
-    render_template = f"djangocms_frontend/{settings.framework}/media-body.html"
     change_form_template = "djangocms_frontend/admin/media.html"
     allow_children = True
     parent_classes = ["MediaPlugin"]
 
-    fieldsets = [
-        (
-            _("Advanced settings"),
-            {
-                "classes": ("collapse",),
-                "fields": (
-                    "tag_type",
-                    "attributes",
-                ),
-            },
-        ),
-    ]
+    fieldsets = settings.EMPTY_FIELDSET
