@@ -1,3 +1,5 @@
+from django.utils.translation import gettext as _
+
 from djangocms_frontend.models import FrontendUIItem
 
 
@@ -9,6 +11,7 @@ class Media(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Media")
 
     def get_short_description(self):
         return ""
@@ -22,6 +25,7 @@ class MediaBody(FrontendUIItem):
 
     class Meta:
         proxy = True
+        verbose_name = _("Media body")
 
     def get_short_description(self):
         return ""
