@@ -9,12 +9,16 @@ class CardModelTestCase(TestCase):
         instance = Card.objects.create().initialize_from_form(CardForm)
         self.assertEqual(str(instance), "Card (1)")
         self.assertEqual(instance.get_short_description(), "")
-        instance.card_context = "primary"
+        instance.config["background_context"] = "primary"
         self.assertEqual(instance.get_short_description(), ".bg-primary")
-        instance.card_outline = True
-        self.assertEqual(instance.get_short_description(), ".border-primary")
+        instance.config["card_outline"] = "secondary"
+        self.assertEqual(
+            instance.get_short_description(), ".bg-primary .border-secondary"
+        )
         instance.card_alignment = "center"
-        self.assertEqual(instance.get_short_description(), ".border-primary .center")
+        self.assertEqual(
+            instance.get_short_description(), ".bg-primary .border-secondary .center"
+        )
 
     def test_card_inner_instance(self):
         instance = CardInner.objects.create().initialize_from_form(CardInnerForm)
